#!/bin/bash
set +ex

HOME_DIR="/home/phablet"

if [ -z "$1" ] || [ -z "$2" ]
then
    echo "You have to pass a device serial and packagearchive link"
    echo "$0 04bf2c50e294d599 archive.zip"
    exit -1
fi

exec_with_adb() {
    adb -s $ANDROID_SERIAL shell "$@"
}

exec_with_adb_user() {
    adb -s $ANDROID_SERIAL shell sudo -i -u phablet bash -ic "$@"
}

ANDROID_SERIAL=$1
packagearchive=$2

echo "Rebooting the phone will take approximately 1.5mins to settle"
adb -s $ANDROID_SERIAL reboot
adb -s $ANDROID_SERIAL wait-for-device
sleep 90

# Set developer mode
rm .dev_mode || true
adb -s $ANDROID_SERIAL pull /.dev_mode
if [[ ! -a .dev_mode ]]; then
    exec_with_adb "touch /userdata/.writable_image"
    exec_with_adb "touch /.dev_mode"
    echo "Rebooting the phone to set dev mode."
    echo "It take approximately 1.5mins to settle"
    adb -s $ANDROID_SERIAL reboot
    adb -s $ANDROID_SERIAL wait-for-device
    sleep 90
fi

# Cleanup old stuff
rm archive.zip *.xml dmesg.log top.log media-info
exec_with_adb "rm -r $HOME_DIR/apexecutor/ $HOME_DIR/archive* "

exec_with_adb 'nmcli dev wifi connect ubuntu-qa-g-wpa password qalabwireless'
exec_with_adb apt-get update
exec_with_adb apt-get -y install unzip autopilot-touch dpkg-dev bzr

wget $packagearchive
adb -s $ANDROID_SERIAL push archive.zip $HOME_DIR
exec_with_adb_user "unzip $HOME_DIR/archive.zip -d $HOME_DIR"

exec_with_adb_user "bzr branch lp:~fginther/+junk/autopilot_executer $HOME_DIR/apexecutor"
exec_with_adb $HOME_DIR/apexecutor/mediumtest_install_packages.sh

exec_with_adb chmod 666 /dev/uinput
exec_with_adb pkill ueventd

# Add the test packages
exec_with_adb "sudo apt-get -y --force-yes install $test_packages"

exec_with_adb "top -n 1 -b | head -20 > /tmp/top.log"
exec_with_adb "dmesg > /tmp/dmesg.log"

# Execute all of the test suites
for suite in $test_suite; do
    if [[ $suite == unity8 ]]; then
        exec_with_adb_user "stop unity8"
        exec_with_adb_user "$HOME_DIR/apexecutor/unlock_screen.py -q"
    else
        exec_with_adb_user $HOME_DIR/apexecutor/unlock_screen.py
    fi
    exec_with_adb sudo -u phablet -i bash -ic "autopilot run -v -o /tmp/${suite}_results.xml -f xml $suite"


    adb -s $ANDROID_SERIAL pull /tmp/${suite}_results.xml
done

exec_with_adb $HOME_DIR/apexecutor/mediumtests_downgrade_pacakges.sh
adb -s $ANDROID_SERIAL pull /tmp/top.log
adb -s $ANDROID_SERIAL pull /tmp/dmesg.log
adb -s $ANDROID_SERIAL pull /etc/media-info
