#!/usr/bin/env python

from autopilot import introspection
from autopilot.display import Display
from autopilot.input import Pointer, Touch
import os
import sys
import subprocess


def help():
    print "Usage:"
    print "Run the script without any argument to unlock with assertion"
    print ""
    print "option -q:"
    print "Execute with parameter -q to unlock the screen quickly without introspection"


def start_unity_in_testability():
    override_file = os.path.expanduser("~/.config/upstart/unity8.override")
    os.system('echo "exec unity8 -testability" > ~/.config/upstart/unity8.override')
    
    pid = int(subprocess.check_output(["pidof", "unity8"]))
    if pid:
        print "Stopping unity"
        os.system('stop -q unity8')
        if os.path.exists("/proc/%d" % pid) is False:
            print "Unity process stopped successfully"
    
    print "Now starting unity in testability mode"
    os.system('start -q unity8')
    pid = int(subprocess.check_output(["pidof", "unity8"]))
    if os.path.exists("/proc/%d" % pid) is True:
        print "Unity is now started "
    
    print "Cleaning up upstart override"
    if os.path.exists(override_file):
        os.remove(override_file)
    
    print "Attempting to unlock the screen"


def unlock_screen():
    input_device = Touch.create()
    pointing_device = Pointer(input_device)
    conn = "com.canonical.Shell.BottomBarVisibilityCommunicator"
    unity8 = introspection.get_proxy_object_for_existing_process(connection_name=conn)
    greeter = unity8.select_single("Greeter")
    x, y, w, h = greeter.globalRect
    tx = int(x + w)
    ty = int(y + (h / 2))

    pointing_device.drag(tx, ty, tx / 2, ty)
    try:
        greeter.shown.wait_for(False)
        print "THE SCREEN UNLOCKED SUCCESSFULLY"
    except:
        AssertionError
        print "The screen could not be unlocked, try restarting the device"


def unlock_screen_blind():
    input_device = Touch.create()
    pointing_device = Pointer(input_device)
    x, y, w, h = Display.create(preferred_backend='UPA').get_screen_geometry(0)
    tx = int(x + w)
    ty = int(y + (h / 2))

    pointing_device.drag(tx, ty, tx / 2, ty)


if len(sys.argv) >= 2 and sys.argv[1] == '-q':
    unlock_screen_blind()
elif len(sys.argv) >= 2 and sys.argv[1] == '-h':
    help()
else:
    start_unity_in_testability()
    unlock_screen()
